import { IWedaRequestParams } from '@cloudbase/cloud-api';
/** 请求云API的参数 */
export interface ICloudApiParams {
    /** yun api 请求的域名, 默认 lowcode */
    service?: string;
    /** 接口版本, 默认 2021-01-08*/
    version?: string;
    /** 接口请求超时时间, 默认30s */
    timeout?: number;
    /** 方法名称 */
    action: string;
    /** 云API参数 */
    data?: Record<string, any>;
    /**
     * 是否自动将 data 的key 改为大写驼峰
     *  默认为 true, 即使用时 data 可以采用小驼峰的 key
     */
    capitalizeDataKey?: boolean;
}
/**
 * 请求云API
 * @param params 配置参数
 */
export declare function fetchCloud(params: ICloudApiParams): Promise<any>;
/**
 * 请求微搭后端运行态API参数
 */
export interface IWedaApiParams extends Partial<Omit<IWedaRequestParams, 'uid' | 'source' | 'requestId' | 'envType'>> {
    /** 方法名称 */
    action: string;
    /** 云API参数 */
    data?: Record<string, any>;
    /**
     * 是否自动将 data 的key 改为大写驼峰
     *  默认为 true, 即使用时 data 可以采用小驼峰的 key
     */
    capitalizeDataKey?: boolean;
    /**
     * 请求ID, 手动设置微搭后端请求的ID
     *  为 true 则复用 云开发云函数的请求ID
     *  为 string 则完全自定义请求ID
     */
    requestId?: boolean | string;
    /**
     * 后台服务类型
     *  runtime 运行时接口
     *  design 设计态接口
     */
    serviceType?: 'runtime' | 'design';
}
/**
 * 请求Weda后台接口
 * @param params 配置参数
 * @param ignoreUser 是否跳过用户信息校验
 */
export declare function fetchWeda(params: IWedaApiParams, ignoreUser?: boolean): Promise<any>;
